# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rqd.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import report_pb2 as report__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\trqd.proto\x12\x03rqd\x1a\x0creport.proto\"\x84\x06\n\x08RunFrame\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\t\x12\x10\n\x08job_name\x18\x03 \x01(\t\x12\x10\n\x08\x66rame_id\x18\x04 \x01(\t\x12\x12\n\nframe_name\x18\x05 \x01(\t\x12\x10\n\x08layer_id\x18\x06 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x07 \x01(\t\x12\x11\n\tuser_name\x18\x08 \x01(\t\x12\x0f\n\x07log_dir\x18\t \x01(\t\x12\x0c\n\x04show\x18\n \x01(\t\x12\x0c\n\x04shot\x18\x0b \x01(\t\x12\x18\n\x0cjob_temp_dir\x18\x0c \x01(\tB\x02\x18\x01\x12\x16\n\x0e\x66rame_temp_dir\x18\r \x01(\t\x12\x14\n\x08log_file\x18\x0e \x01(\tB\x02\x18\x01\x12\x18\n\x0clog_dir_file\x18\x0f \x01(\tB\x02\x18\x01\x12\x12\n\nstart_time\x18\x10 \x01(\x03\x12\r\n\x03uid\x18\x11 \x01(\x05H\x00\x12\x11\n\tnum_cores\x18\x12 \x01(\x05\x12\x0b\n\x03gid\x18\x13 \x01(\x05\x12\x14\n\x0cignore_nimby\x18\x14 \x01(\x08\x12\x33\n\x0b\x65nvironment\x18\x15 \x03(\x0b\x32\x1e.rqd.RunFrame.EnvironmentEntry\x12\x31\n\nattributes\x18\x16 \x03(\x0b\x32\x1d.rqd.RunFrame.AttributesEntry\x12\x10\n\x08num_gpus\x18\x17 \x01(\x05\x12+\n\x08\x63hildren\x18\x18 \x01(\x0b\x32\x19.report.ChildrenProcStats\x12\n\n\x02os\x18\x19 \x01(\t\x12\x19\n\x11soft_memory_limit\x18\x1a \x01(\x03\x12\x19\n\x11hard_memory_limit\x18\x1b \x01(\x03\x12\x0b\n\x03pid\x18\x1c \x01(\x05\x12\x10\n\x08loki_url\x18\x1d \x01(\t\x1a\x32\n\x10\x45nvironmentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0e\n\x0cuid_optional\"0\n\x0bRunFrameSeq\x12!\n\nrun_frames\x18\x01 \x03(\x0b\x32\r.rqd.RunFrame\"g\n\x1bRqdStaticGetRunFrameRequest\x12\x10\n\x08\x66rame_id\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\t\x12\x10\n\x08layer_id\x18\x03 \x01(\t\x12\x14\n\x0crun_frame_id\x18\x04 \x01(\x05\"@\n\x1cRqdStaticGetRunFrameResponse\x12 \n\trun_frame\x18\x01 \x01(\x0b\x32\r.rqd.RunFrame\"9\n%RqdStaticGetRunningFrameStatusRequest\x12\x10\n\x08\x66rame_id\x18\x01 \x01(\t\"^\n&RqdStaticGetRunningFrameStatusResponse\x12\x34\n\x12running_frame_info\x18\x01 \x01(\x0b\x32\x18.report.RunningFrameInfo\"E\n RqdStaticKillRunningFrameRequest\x12\x10\n\x08\x66rame_id\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\"#\n!RqdStaticKillRunningFrameResponse\"?\n\x1bRqdStaticLaunchFrameRequest\x12 \n\trun_frame\x18\x01 \x01(\x0b\x32\r.rqd.RunFrame\"\x1e\n\x1cRqdStaticLaunchFrameResponse\"\x19\n\x17RqdStaticLockAllRequest\"\x1a\n\x18RqdStaticLockAllResponse\"%\n\x14RqdStaticLockRequest\x12\r\n\x05\x63ores\x18\x01 \x01(\x05\"\x17\n\x15RqdStaticLockResponse\"\x1a\n\x18RqdStaticNimbyOffRequest\"\x1b\n\x19RqdStaticNimbyOffResponse\"\x19\n\x17RqdStaticNimbyOnRequest\"\x1a\n\x18RqdStaticNimbyOnResponse\"\x1c\n\x1aRqdStaticRebootIdleRequest\"\x1d\n\x1bRqdStaticRebootIdleResponse\"\x1b\n\x19RqdStaticRebootNowRequest\"\x1c\n\x1aRqdStaticRebootNowResponse\"\x1e\n\x1cRqdStaticReportStatusRequest\"H\n\x1dRqdStaticReportStatusResponse\x12\'\n\x0bhost_report\x18\x01 \x01(\x0b\x32\x12.report.HostReport\"\x1d\n\x1bRqdStaticRestartIdleRequest\"\x1e\n\x1cRqdStaticRestartIdleResponse\"\x1c\n\x1aRqdStaticRestartNowRequest\"\x1d\n\x1bRqdStaticRestartNowResponse\"\x1e\n\x1cRqdStaticShutdownIdleRequest\"\x1f\n\x1dRqdStaticShutdownIdleResponse\"\x1d\n\x1bRqdStaticShutdownNowRequest\"\x1e\n\x1cRqdStaticShutdownNowResponse\"\'\n\x16RqdStaticUnlockRequest\x12\r\n\x05\x63ores\x18\x01 \x01(\x05\"\x19\n\x17RqdStaticUnlockResponse\"\x1b\n\x19RqdStaticUnlockAllRequest\"\x1c\n\x1aRqdStaticUnlockAllResponse\"L\n\x17RunningFrameKillRequest\x12 \n\trun_frame\x18\x01 \x01(\x0b\x32\r.rqd.RunFrame\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x1a\n\x18RunningFrameKillResponse\"=\n\x19RunningFrameStatusRequest\x12 \n\trun_frame\x18\x01 \x01(\x0b\x32\r.rqd.RunFrame\"R\n\x1aRunningFrameStatusResponse\x12\x34\n\x12running_frame_info\x18\x01 \x01(\x0b\x32\x18.report.RunningFrameInfo*%\n\tErrorCode\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x32\x8a\x0b\n\x0cRqdInterface\x12R\n\x0bGetRunFrame\x12 .rqd.RqdStaticGetRunFrameRequest\x1a!.rqd.RqdStaticGetRunFrameResponse\x12p\n\x15GetRunningFrameStatus\x12*.rqd.RqdStaticGetRunningFrameStatusRequest\x1a+.rqd.RqdStaticGetRunningFrameStatusResponse\x12\x61\n\x10KillRunningFrame\x12%.rqd.RqdStaticKillRunningFrameRequest\x1a&.rqd.RqdStaticKillRunningFrameResponse\x12R\n\x0bLaunchFrame\x12 .rqd.RqdStaticLaunchFrameRequest\x1a!.rqd.RqdStaticLaunchFrameResponse\x12=\n\x04Lock\x12\x19.rqd.RqdStaticLockRequest\x1a\x1a.rqd.RqdStaticLockResponse\x12\x46\n\x07LockAll\x12\x1c.rqd.RqdStaticLockAllRequest\x1a\x1d.rqd.RqdStaticLockAllResponse\x12I\n\x08NimbyOff\x12\x1d.rqd.RqdStaticNimbyOffRequest\x1a\x1e.rqd.RqdStaticNimbyOffResponse\x12\x46\n\x07NimbyOn\x12\x1c.rqd.RqdStaticNimbyOnRequest\x1a\x1d.rqd.RqdStaticNimbyOnResponse\x12O\n\nRebootIdle\x12\x1f.rqd.RqdStaticRebootIdleRequest\x1a .rqd.RqdStaticRebootIdleResponse\x12L\n\tRebootNow\x12\x1e.rqd.RqdStaticRebootNowRequest\x1a\x1f.rqd.RqdStaticRebootNowResponse\x12U\n\x0cReportStatus\x12!.rqd.RqdStaticReportStatusRequest\x1a\".rqd.RqdStaticReportStatusResponse\x12U\n\x0eRestartRqdIdle\x12 .rqd.RqdStaticRestartIdleRequest\x1a!.rqd.RqdStaticRestartIdleResponse\x12R\n\rRestartRqdNow\x12\x1f.rqd.RqdStaticRestartNowRequest\x1a .rqd.RqdStaticRestartNowResponse\x12X\n\x0fShutdownRqdIdle\x12!.rqd.RqdStaticShutdownIdleRequest\x1a\".rqd.RqdStaticShutdownIdleResponse\x12U\n\x0eShutdownRqdNow\x12 .rqd.RqdStaticShutdownNowRequest\x1a!.rqd.RqdStaticShutdownNowResponse\x12\x43\n\x06Unlock\x12\x1b.rqd.RqdStaticUnlockRequest\x1a\x1c.rqd.RqdStaticUnlockResponse\x12L\n\tUnlockAll\x12\x1e.rqd.RqdStaticUnlockAllRequest\x1a\x1f.rqd.RqdStaticUnlockAllResponse2\x9e\x01\n\x0cRunningFrame\x12\x43\n\x04Kill\x12\x1c.rqd.RunningFrameKillRequest\x1a\x1d.rqd.RunningFrameKillResponse\x12I\n\x06Status\x12\x1e.rqd.RunningFrameStatusRequest\x1a\x1f.rqd.RunningFrameStatusResponseB9\n\x1d\x63om.imageworks.spcue.grpc.rqdP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'rqd_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035com.imageworks.spcue.grpc.rqdP\001Z\026opencue_gateway/gen/go'
  _globals['_RUNFRAME_ENVIRONMENTENTRY']._options = None
  _globals['_RUNFRAME_ENVIRONMENTENTRY']._serialized_options = b'8\001'
  _globals['_RUNFRAME_ATTRIBUTESENTRY']._options = None
  _globals['_RUNFRAME_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_RUNFRAME'].fields_by_name['job_temp_dir']._options = None
  _globals['_RUNFRAME'].fields_by_name['job_temp_dir']._serialized_options = b'\030\001'
  _globals['_RUNFRAME'].fields_by_name['log_file']._options = None
  _globals['_RUNFRAME'].fields_by_name['log_file']._serialized_options = b'\030\001'
  _globals['_RUNFRAME'].fields_by_name['log_dir_file']._options = None
  _globals['_RUNFRAME'].fields_by_name['log_dir_file']._serialized_options = b'\030\001'
  _globals['_ERRORCODE']._serialized_start=2477
  _globals['_ERRORCODE']._serialized_end=2514
  _globals['_RUNFRAME']._serialized_start=33
  _globals['_RUNFRAME']._serialized_end=805
  _globals['_RUNFRAME_ENVIRONMENTENTRY']._serialized_start=688
  _globals['_RUNFRAME_ENVIRONMENTENTRY']._serialized_end=738
  _globals['_RUNFRAME_ATTRIBUTESENTRY']._serialized_start=740
  _globals['_RUNFRAME_ATTRIBUTESENTRY']._serialized_end=789
  _globals['_RUNFRAMESEQ']._serialized_start=807
  _globals['_RUNFRAMESEQ']._serialized_end=855
  _globals['_RQDSTATICGETRUNFRAMEREQUEST']._serialized_start=857
  _globals['_RQDSTATICGETRUNFRAMEREQUEST']._serialized_end=960
  _globals['_RQDSTATICGETRUNFRAMERESPONSE']._serialized_start=962
  _globals['_RQDSTATICGETRUNFRAMERESPONSE']._serialized_end=1026
  _globals['_RQDSTATICGETRUNNINGFRAMESTATUSREQUEST']._serialized_start=1028
  _globals['_RQDSTATICGETRUNNINGFRAMESTATUSREQUEST']._serialized_end=1085
  _globals['_RQDSTATICGETRUNNINGFRAMESTATUSRESPONSE']._serialized_start=1087
  _globals['_RQDSTATICGETRUNNINGFRAMESTATUSRESPONSE']._serialized_end=1181
  _globals['_RQDSTATICKILLRUNNINGFRAMEREQUEST']._serialized_start=1183
  _globals['_RQDSTATICKILLRUNNINGFRAMEREQUEST']._serialized_end=1252
  _globals['_RQDSTATICKILLRUNNINGFRAMERESPONSE']._serialized_start=1254
  _globals['_RQDSTATICKILLRUNNINGFRAMERESPONSE']._serialized_end=1289
  _globals['_RQDSTATICLAUNCHFRAMEREQUEST']._serialized_start=1291
  _globals['_RQDSTATICLAUNCHFRAMEREQUEST']._serialized_end=1354
  _globals['_RQDSTATICLAUNCHFRAMERESPONSE']._serialized_start=1356
  _globals['_RQDSTATICLAUNCHFRAMERESPONSE']._serialized_end=1386
  _globals['_RQDSTATICLOCKALLREQUEST']._serialized_start=1388
  _globals['_RQDSTATICLOCKALLREQUEST']._serialized_end=1413
  _globals['_RQDSTATICLOCKALLRESPONSE']._serialized_start=1415
  _globals['_RQDSTATICLOCKALLRESPONSE']._serialized_end=1441
  _globals['_RQDSTATICLOCKREQUEST']._serialized_start=1443
  _globals['_RQDSTATICLOCKREQUEST']._serialized_end=1480
  _globals['_RQDSTATICLOCKRESPONSE']._serialized_start=1482
  _globals['_RQDSTATICLOCKRESPONSE']._serialized_end=1505
  _globals['_RQDSTATICNIMBYOFFREQUEST']._serialized_start=1507
  _globals['_RQDSTATICNIMBYOFFREQUEST']._serialized_end=1533
  _globals['_RQDSTATICNIMBYOFFRESPONSE']._serialized_start=1535
  _globals['_RQDSTATICNIMBYOFFRESPONSE']._serialized_end=1562
  _globals['_RQDSTATICNIMBYONREQUEST']._serialized_start=1564
  _globals['_RQDSTATICNIMBYONREQUEST']._serialized_end=1589
  _globals['_RQDSTATICNIMBYONRESPONSE']._serialized_start=1591
  _globals['_RQDSTATICNIMBYONRESPONSE']._serialized_end=1617
  _globals['_RQDSTATICREBOOTIDLEREQUEST']._serialized_start=1619
  _globals['_RQDSTATICREBOOTIDLEREQUEST']._serialized_end=1647
  _globals['_RQDSTATICREBOOTIDLERESPONSE']._serialized_start=1649
  _globals['_RQDSTATICREBOOTIDLERESPONSE']._serialized_end=1678
  _globals['_RQDSTATICREBOOTNOWREQUEST']._serialized_start=1680
  _globals['_RQDSTATICREBOOTNOWREQUEST']._serialized_end=1707
  _globals['_RQDSTATICREBOOTNOWRESPONSE']._serialized_start=1709
  _globals['_RQDSTATICREBOOTNOWRESPONSE']._serialized_end=1737
  _globals['_RQDSTATICREPORTSTATUSREQUEST']._serialized_start=1739
  _globals['_RQDSTATICREPORTSTATUSREQUEST']._serialized_end=1769
  _globals['_RQDSTATICREPORTSTATUSRESPONSE']._serialized_start=1771
  _globals['_RQDSTATICREPORTSTATUSRESPONSE']._serialized_end=1843
  _globals['_RQDSTATICRESTARTIDLEREQUEST']._serialized_start=1845
  _globals['_RQDSTATICRESTARTIDLEREQUEST']._serialized_end=1874
  _globals['_RQDSTATICRESTARTIDLERESPONSE']._serialized_start=1876
  _globals['_RQDSTATICRESTARTIDLERESPONSE']._serialized_end=1906
  _globals['_RQDSTATICRESTARTNOWREQUEST']._serialized_start=1908
  _globals['_RQDSTATICRESTARTNOWREQUEST']._serialized_end=1936
  _globals['_RQDSTATICRESTARTNOWRESPONSE']._serialized_start=1938
  _globals['_RQDSTATICRESTARTNOWRESPONSE']._serialized_end=1967
  _globals['_RQDSTATICSHUTDOWNIDLEREQUEST']._serialized_start=1969
  _globals['_RQDSTATICSHUTDOWNIDLEREQUEST']._serialized_end=1999
  _globals['_RQDSTATICSHUTDOWNIDLERESPONSE']._serialized_start=2001
  _globals['_RQDSTATICSHUTDOWNIDLERESPONSE']._serialized_end=2032
  _globals['_RQDSTATICSHUTDOWNNOWREQUEST']._serialized_start=2034
  _globals['_RQDSTATICSHUTDOWNNOWREQUEST']._serialized_end=2063
  _globals['_RQDSTATICSHUTDOWNNOWRESPONSE']._serialized_start=2065
  _globals['_RQDSTATICSHUTDOWNNOWRESPONSE']._serialized_end=2095
  _globals['_RQDSTATICUNLOCKREQUEST']._serialized_start=2097
  _globals['_RQDSTATICUNLOCKREQUEST']._serialized_end=2136
  _globals['_RQDSTATICUNLOCKRESPONSE']._serialized_start=2138
  _globals['_RQDSTATICUNLOCKRESPONSE']._serialized_end=2163
  _globals['_RQDSTATICUNLOCKALLREQUEST']._serialized_start=2165
  _globals['_RQDSTATICUNLOCKALLREQUEST']._serialized_end=2192
  _globals['_RQDSTATICUNLOCKALLRESPONSE']._serialized_start=2194
  _globals['_RQDSTATICUNLOCKALLRESPONSE']._serialized_end=2222
  _globals['_RUNNINGFRAMEKILLREQUEST']._serialized_start=2224
  _globals['_RUNNINGFRAMEKILLREQUEST']._serialized_end=2300
  _globals['_RUNNINGFRAMEKILLRESPONSE']._serialized_start=2302
  _globals['_RUNNINGFRAMEKILLRESPONSE']._serialized_end=2328
  _globals['_RUNNINGFRAMESTATUSREQUEST']._serialized_start=2330
  _globals['_RUNNINGFRAMESTATUSREQUEST']._serialized_end=2391
  _globals['_RUNNINGFRAMESTATUSRESPONSE']._serialized_start=2393
  _globals['_RUNNINGFRAMESTATUSRESPONSE']._serialized_end=2475
  _globals['_RQDINTERFACE']._serialized_start=2517
  _globals['_RQDINTERFACE']._serialized_end=3935
  _globals['_RUNNINGFRAME']._serialized_start=3938
  _globals['_RUNNINGFRAME']._serialized_end=4096
# @@protoc_insertion_point(module_scope)


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import depend_pb2 as depend__pb2


class DependInterfaceStub(object):
    """-------- Services --------

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetDepend = channel.unary_unary(
                '/depend.DependInterface/GetDepend',
                request_serializer=depend__pb2.DependGetDependRequest.SerializeToString,
                response_deserializer=depend__pb2.DependGetDependResponse.FromString,
                )
        self.Satisfy = channel.unary_unary(
                '/depend.DependInterface/Satisfy',
                request_serializer=depend__pb2.DependSatisfyRequest.SerializeToString,
                response_deserializer=depend__pb2.DependSatisfyResponse.FromString,
                )
        self.Unsatisfy = channel.unary_unary(
                '/depend.DependInterface/Unsatisfy',
                request_serializer=depend__pb2.DependUnsatisfyRequest.SerializeToString,
                response_deserializer=depend__pb2.DependUnsatisfyResponse.FromString,
                )


class DependInterfaceServicer(object):
    """-------- Services --------

    """

    def GetDepend(self, request, context):
        """Get a Depend by it's id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Satisfy(self, request, context):
        """Satisfies the dependency which sets any frames waiting on this dependency to the WAITING state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Unsatisfy(self, request, context):
        """Unsatisfies the dependency making it active again and sets matching frames to DEPEND
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DependInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetDepend': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDepend,
                    request_deserializer=depend__pb2.DependGetDependRequest.FromString,
                    response_serializer=depend__pb2.DependGetDependResponse.SerializeToString,
            ),
            'Satisfy': grpc.unary_unary_rpc_method_handler(
                    servicer.Satisfy,
                    request_deserializer=depend__pb2.DependSatisfyRequest.FromString,
                    response_serializer=depend__pb2.DependSatisfyResponse.SerializeToString,
            ),
            'Unsatisfy': grpc.unary_unary_rpc_method_handler(
                    servicer.Unsatisfy,
                    request_deserializer=depend__pb2.DependUnsatisfyRequest.FromString,
                    response_serializer=depend__pb2.DependUnsatisfyResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'depend.DependInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DependInterface(object):
    """-------- Services --------

    """

    @staticmethod
    def GetDepend(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/depend.DependInterface/GetDepend',
            depend__pb2.DependGetDependRequest.SerializeToString,
            depend__pb2.DependGetDependResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Satisfy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/depend.DependInterface/Satisfy',
            depend__pb2.DependSatisfyRequest.SerializeToString,
            depend__pb2.DependSatisfyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Unsatisfy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/depend.DependInterface/Unsatisfy',
            depend__pb2.DependUnsatisfyRequest.SerializeToString,
            depend__pb2.DependUnsatisfyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import task_pb2 as task__pb2


class TaskInterfaceStub(object):
    """Tasks
    Tasks are shot priorities for a specific dept

    -------- Services --------]

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ClearAdjustments = channel.unary_unary(
                '/task.TaskInterface/ClearAdjustments',
                request_serializer=task__pb2.TaskClearAdjustmentsRequest.SerializeToString,
                response_deserializer=task__pb2.TaskClearAdjustmentsResponse.FromString,
                )
        self.Delete = channel.unary_unary(
                '/task.TaskInterface/Delete',
                request_serializer=task__pb2.TaskDeleteRequest.SerializeToString,
                response_deserializer=task__pb2.TaskDeleteResponse.FromString,
                )
        self.SetMinCores = channel.unary_unary(
                '/task.TaskInterface/SetMinCores',
                request_serializer=task__pb2.TaskSetMinCoresRequest.SerializeToString,
                response_deserializer=task__pb2.TaskSetMinCoresResponse.FromString,
                )


class TaskInterfaceServicer(object):
    """Tasks
    Tasks are shot priorities for a specific dept

    -------- Services --------]

    """

    def ClearAdjustments(self, request, context):
        """Clear any min core adjustments that have been made
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Removes the task.  If the department is managed the task is likely to come back upon the next update.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetMinCores(self, request, context):
        """Sets the minimum number of cores.  If the task is being managed, then the min core value is adjusted
        but the original is not changed.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TaskInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ClearAdjustments': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearAdjustments,
                    request_deserializer=task__pb2.TaskClearAdjustmentsRequest.FromString,
                    response_serializer=task__pb2.TaskClearAdjustmentsResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=task__pb2.TaskDeleteRequest.FromString,
                    response_serializer=task__pb2.TaskDeleteResponse.SerializeToString,
            ),
            'SetMinCores': grpc.unary_unary_rpc_method_handler(
                    servicer.SetMinCores,
                    request_deserializer=task__pb2.TaskSetMinCoresRequest.FromString,
                    response_serializer=task__pb2.TaskSetMinCoresResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'task.TaskInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TaskInterface(object):
    """Tasks
    Tasks are shot priorities for a specific dept

    -------- Services --------]

    """

    @staticmethod
    def ClearAdjustments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/task.TaskInterface/ClearAdjustments',
            task__pb2.TaskClearAdjustmentsRequest.SerializeToString,
            task__pb2.TaskClearAdjustmentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/task.TaskInterface/Delete',
            task__pb2.TaskDeleteRequest.SerializeToString,
            task__pb2.TaskDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetMinCores(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/task.TaskInterface/SetMinCores',
            task__pb2.TaskSetMinCoresRequest.SerializeToString,
            task__pb2.TaskSetMinCoresResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)